@@ -43,13 +43,17 @@ class SmartApp:
             SmartExplainer instance to point to.
     """
 
-    def __init__(self, explainer):
+    def __init__(self, explainer, settings: dict = None):
         """
         Init on class instantiation, everything to be able to run the app on server.
         Parameters
         ----------
         explainer : SmartExplainer
             SmartExplainer object
+        settings : dict
+            A dict describing the default webapp settings values to be used
+            Possible settings (dict keys) are 'rows', 'points', 'violin', 'features'
+            Values should be positive ints
         """
         # APP
         self.server = Flask(__name__)
@@ -72,7 +76,12 @@ class SmartApp:
             'violin': 10,
             'features': 20,
         }
+        if settings is not None:
+            for k, v in self.settings_ini.items():
+                self.settings_ini[k] = settings[k] if k in settings and isinstance(settings[k], int) and 0 < settings[k] else v
+                
         self.settings = self.settings_ini.copy()
+
         self.predict_col = ['_predict_']
         self.explainer.features_imp = self.explainer.state.compute_features_import(self.explainer.contributions)
         if self.explainer._case == 'classification':
@@ -1060,6 +1069,7 @@ class SmartApp:
                 Input('select_label', 'value'),
                 Input('dataset', 'active_cell'),
                 Input('feature_selector', 'clickData'),
+                Input("validation", "n_clicks"),
                 Input('bool_groups', 'on')
             ],
             [
@@ -1068,7 +1078,7 @@ class SmartApp:
             ]
         )
         def update_detail_feature(threshold, max_contrib, positive, negative, masked, label, cell,
-                                  click_data, bool_group, index, data):
+                                  click_data, validation_click, bool_group, index, data):
             """
             update local explanation plot according to app changes.
             """
@@ -1076,7 +1086,7 @@ class SmartApp:
             selected = None
             if ctx.triggered[0]['prop_id'] == 'feature_selector.clickData':
                 selected = click_data['points'][0]['customdata']
-            elif ctx.triggered[0]['prop_id'] == 'threshold_id.value':
+            elif ctx.triggered[0]['prop_id'] in ['threshold_id.value', 'validation.n_clicks']:
                 selected = index
             elif ctx.triggered[0]['prop_id'] == 'dataset.active_cell':
                 if cell:
@@ -1085,10 +1095,7 @@ class SmartApp:
                     raise PreventUpdate
 
             if selected is None:
-                if cell is not None:
-                    selected = data[cell['row']]['_index_']
-                else:
-                    selected = index
+                selected = index
 
             threshold = threshold if threshold != 0 else None
             if positive == [1]:
